@@ -10,6 +10,7 @@ EXTENSIONS = {
     'asar': {'binary', 'asar'},
     'bash': {'text', 'shell', 'bash'},
     'bat': {'text', 'batch'},
+    'bib': {'text', 'bib'},
     'bmp': {'binary', 'image', 'bitmap'},
     'bz2': {'binary', 'bzip2'},
     'c': {'text', 'c'},
@@ -164,6 +165,7 @@ EXTENSIONS = {
     'swiftdeps': {'text', 'swiftdeps'},
     'tac': {'text', 'twisted', 'python'},
     'tar': {'binary', 'tar'},
+    'tex': {'text', 'tex'},
     'tf': {'text', 'terraform'},
     'tfvars': {'text', 'terraform'},
     'tgz': {'binary', 'gzip'},
